pub struct MailConfig { /* private fields */ }Expand description
A struct representing a full mail configuration, required for working with this library
For convenience reasons, this implements Serialize and Deserialize, so it can be fetched from a configuration file for example
TODO
Figure out how to use handlebars with variables on this. Right now the support for that is not implemented yet.
Implementations
Sourceimpl MailConfig
impl MailConfig
pub fn default_account(&self) -> &String
pub fn accounts(&self) -> &Vec<MailAccountConfig>
pub fn account(&self, name: &str) -> Option<&MailAccountConfig>
pub fn fetchcommand(&self) -> &MailCommand
pub fn postfetchcommand(&self) -> Option<&MailCommand>
pub fn sendcommand(&self) -> &MailCommand
pub fn postsendcommand(&self) -> Option<&MailCommand>
pub fn fetchcommand_for_account(&self, account_name: &str) -> &MailCommand
pub fn postfetchcommand_for_account( &self, account_name: &str, ) -> Option<&MailCommand>
pub fn sendcommand_for_account(&self, account_name: &str) -> &MailCommand
pub fn postsendcommand_for_account( &self, account_name: &str, ) -> Option<&MailCommand>